
// thumbnails in overview
.workspace-thumbnails {
  color: $osd_fg_color;
  background-color: transparentize($osd_fg_color, 0.9);
  visible-width: 32px; //amount visible before hover
  spacing: $cont_padding;
  padding: $cont_padding;
  border-radius: $bt_radius 0 0 $bt_radius;
  border-right-width: 0;

  &:rtl {
    border-radius: 0 $bt_radius $bt_radius 0;
    border-left-width: 0;
  }

  // drag and drop indicator
  .placeholder {
    background-image: url("resource:///org/gnome/shell/theme/dash-placeholder.svg");
    background-size: contain;
    height: 24px;
  }
}
