/* Window Picker */

$window_picker_spacing: 6px; // 6px
$window_picker_padding: 12px; // 12px

$window_thumbnail_border_color: transparentize($selected_fg_color, 0.65);

$window_close_button_size: 32px;
$window_close_button_padding: 3px;

$window_clone_border_size: 3px;

// Window picker
.window-picker {
  // Space between window thumbnails
  spacing: $window_picker_spacing;

  // Padding for container around window thumbnails
  padding: $window_picker_padding;

  &.external-monitor { padding: $window_picker_padding; }
}

// Borders on window thumbnails
.window-clone-border {
  border-width: $window_clone_border_size;
  border-style: solid;
  border-color: $window_thumbnail_border_color;
  border-radius: $bt_radius;
  // For window decorations with round corners we can't match
  // the exact shape when the window is scaled. So apply a shadow
  // to fix that case
  box-shadow: inset 0 0 0 1px transparentize($borders_color, 0.8);
}

// Window titles
.window-caption {
  color: $osd_fg_color;
  background-color: $osd_bg_color;
  border: 1px solid rgba(black, 0.75);
  border-radius: $bt_radius;
  padding: 3px 12px;
  font-weight: normal;
  @include fontsize($font-size);
}

// Close button
.window-close {
  background-color: $wm_button_close_bg;
  color: $selected_fg_color;
  border: none;
  border-radius: $window_close_button_size * 0.5 + $window_close_button_padding * 2;
  padding: $window_close_button_padding;
  height: $window_close_button_size;
  width: $window_close_button_size;
  box-shadow: -1px 1px 5px 0px rgba(0,0,0, 0.5);
  transition-duration: 300ms;

  -shell-close-overlap: $window_close_button_size * 0.5; // 3.36.0

  &:hover {
    background-color: lighten($wm_button_close_hover_bg, 5%);
  }

  &:active {
    background-color: darken($wm_button_close_active_bg, 5%);
  }
}
