/* Buttons */

@use "../../../../theme";
@use "../../drawing";
@use "../../typography";

%button,
.button {
  min-height: theme.$medium-size;
  min-width: 64px - 8px * 2;
  padding: 0 8px;
  border: 0;
  border-radius: theme.$corner-radius;

  @include typography.button;
  @include drawing.button(flat-normal);

  &:focus {
    @include drawing.button(flat-focus);
  }

  &:hover {
    @include drawing.button(flat-hover);
  }

  &:active {
    @include drawing.button(flat-active);
  }

  &:insensitive {
    @include drawing.button(flat-insensitive);
  }
}

// buttons in dialogs and notifications
%bubble_button {
  @extend %button;
  margin: theme.$container-padding;
  margin-right: 0;

  &:first-child,
  &:last-child,
  &:first-child:last-child {
    border-radius: theme.$corner-radius;
  }

  &:last-child,
  &:first-child:last-child {
    margin-right: theme.$container-padding;
    border-right-width: 0;
  }
}
