/* Entries */

@use "../../../../theme";
@use "../../../../theme-color";
@use "../../gnome-shell";
@use "../../drawing";
@use "../../typography";

%entry,
StEntry {
  min-height: theme.$medium-size;
  padding: 0 8px;
  border-width: 0;
  border-radius: theme.$corner-radius theme.$corner-radius 0 0;
  color: theme-color.$on-surface;
  selection-background-color: theme-color.$selected-overlay;
  selected-color: theme-color.$on-surface;
  @include typography.body1;
  @include drawing.entry(normal);

  &:hover {
    @include drawing.entry(hover);
  }

  &:focus {
    @include drawing.entry(focus);

    @if gnome-shell.$version == 3.34 {
      border: 0;
    }
  }

  &:insensitive {
    @include drawing.entry(insensitive);
  }

  StIcon.capslock-warning {
    icon-size: 16px;
    padding: 0 4px;
    warning-color: theme-color.$warning;
  }

  StIcon.peek-password {
    icon-size: 16px;
    padding: 0 4px;
    color: theme-color.hint(theme-color.$on-surface);

    &:hover {
      color: theme-color.$on-surface;
    }
  }

  StLabel.hint-text {
    margin-left: 2px;
    color: theme-color.hint(theme-color.$on-surface);
  }
}
