/* Switches */

.toggle-switch {
  width: 50px;
  height: 20px;
  background-size: contain;
  background-image: url("assets/switch-off.svg");

  &:checked { background-image: url("assets/switch-on.svg"); }

  .popup-menu-item:hover &,
  .popup-menu-item:focus &,
  .popup-menu-item.selected & {
    background-image: url("assets/switch-off-selected.svg");

    &:checked { background-image: url("assets/switch-on-selected.svg"); }
  }
}
