/* Switches */

.toggle-switch {
  color: inherit;
  width: 40px;
  height: 24px;
  background-size: contain;
  background-image: url("assets/toggle-off.svg");

  &:checked {
    background-image: url("assets/toggle-on.svg");
  }
}
