/* Slider */

.slider {
  height: 20px;
  color: $base_color;

  -slider-height: 4px;
  -slider-background-color: $button_border;                   //background of the trough
  -slider-border-color: transparent;                          //trough border color
  -slider-active-background-color: $selected_bg_color;        //active trough fill
  -slider-active-border-color: transparent;                   //active trough border
  -slider-border-width: 0;
  -slider-handle-radius: 9px;
  -slider-handle-border-width: 1px;
  -slider-handle-border-color: $borders_color;

  // barlevels are for >= 3.29.90
  -barlevel-height: 4px;
  -barlevel-background-color: $button_border;
  -barlevel-border-width: 0;
  -barlevel-border-color: transparent;
  -barlevel-active-background-color: $selected_bg_color;
  -barlevel-active-border-color: transparent;
  -barlevel-overdrive-color: $destructive_color;
  -barlevel-overdrive-border-color: $destructive_color;
  -barlevel-overdrive-separator-width: 2px;

  .popup-menu-item:hover &,
  .popup-menu-item:focus &,
  .popup-menu-item.selected & {
    -slider-background-color: rgba(black, 0.2);
    -slider-active-background-color: $selected_fg_color;

    // barlevels are for >= 3.29.90
    -barlevel-background-color: rgba(black, 0.2);
    -barlevel-active-background-color: $selected_fg_color;
  }
}
